@@ -3,5 +3,9 @@
 from dmm_api.client import DMMApiClient
 from dmm_api.crawler import Crawler
 
-DMMApiClient = DMMApiClient
-Crawler = Crawler
+__version__ = '0.1.4'
+
+__all__ = [
+    'DMMApiClient',
+    'Crawler',
+]
